InitConfig class
Constructors
Properties
- apiRest → ApiRest
-
no setter
- apiRestEnableDebugLogs → bool
-
final
- authApiRest ↔ AuthApiRest
-
getter/setter pair
- authApiRestEnableDebugLogs → bool
-
final
- cloudDBEnableDebugLogs → bool
-
final
- coleccionAuth ↔ String
-
Coleccion de autenticacion. Es la coleccion donde se guardan los usuarios
ejemplo 'usuario', 'usuariosENX, etc
getter/setter pair
- coleccionSeguridad ↔ String
-
getter/setter pair
- dynamicEnableDebugLogs → bool
-
final
- eliminaVacio → bool
-
final
- endpointSocket ↔ String
-
getter/setter pair
- funcionesServicios ↔ FuncionesServicios?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lstApartadosAMostrar
↔ List<
String> -
Si tiene algun valor se utiliza solo estos valores para mostrar en el menu
de apartados. Si no tiene ningun valor se mostraran todos los apartados
que tenga la coleccion
getter/setter pair
-
lstColeccionesExtrasAuth
↔ List<
ItemModel> -
Si en la app se va poder configurar la seguridad para mas de una coleccion
se debe pasar una lista de colecciones extras
En esta lista debe estar el mismo valor que coleccionAuth. Los valores que posea debe tener el siguiente formato
{ "idItem":'usuariosENXSeguridad' "descripcionItem":'Seguridad de usuarios ENX' }, { "idItem":"genesisSeguridad", "descripcionItem":"Seguridad de genesis" }Todos los idItem deben terminar con la palabra Seguridad que es la que se encarga de administrar la seguridad de la colecciongetter/setter pair - origenColeccion ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- soloColeccionesOrigen ↔ bool
-
getter/setter pair
- theme → ThemeCDM
-
final
- themeData → ThemeCDM
-
no setter
- utilProviderEnableDebugLogs → bool
-
final
- utilsDataApiRest ↔ UtilsDataApiRest?
-
getter/setter pair
- versionApp → String
-
no setter
Methods
-
blocInicio(
) → List -
init(
{required String clientId, required String clientSecret, required String endpointApi, required String endpointAuth, required String endpointSocket, required RedirectUri redirectUri, required String origenColeccion, required String coleccionFuncionesBackend, required bool soloColeccionesOrigen, required String coleccionAuth, required List< ItemModel> lstColeccionesExtrasAuth, bool enableDebugLogs = false, bool initTheme = true, ThemeData? lightTheme, List<String> lstApartadosAMostrar = const [], ThemeData? darkTheme}) → Future<bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited