MyAppDynamic class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MyAppDynamic
Constructors
-
MyAppDynamic({Key? key, required Widget homePageBuilder(Widget), Widget loginPageBuilder(Widget)?, Map<
String, dynamic Function(BuildContext, GoRouterState)> lstRouteAdicionales = const <String, Function(BuildContext, GoRouterState)>{}, Map<String, dynamic Function(BuildContext, GoRouterState)> lstRouteAdicionalesLogin = const <String, Function(BuildContext, GoRouterState)>{}, required String rootRoute, dynamic onRedirect(BuildContext, GoRouterState)?, String? loginRoute, required RedirectUri redirectUri, required String originColeccion, required String title, bool soloColeccionesOrigen = true, ThemeData? lightTheme, ThemeData? darkTheme, required String coleccionFuncionesBackend, required List<RouteItem> lstVistasSistema, required String coleccionAuth, List<ItemModel> lstColeccionesExtrasAuth = const [], List<String> coleccionesExtras = const [], required String clientId, required String clientSecret, required String endpointApi, required String endpointAuth, required String endpointSocket, Map<String, CustomWidgetBuilder> customWidgetBuilders = const {}, Widget? loginRouteWidget, bool dynamicEnableDebugLogs = false, bool cloudDBEnableDebugLogs = false, bool authApiRestEnableDebugLogs = false, bool utilProviderEnableDebugLogs = false, bool apiRestEnableDebugLogs = false, bool agregaListenersDynamicCrud = true}) -
const
Properties
- agregaListenersDynamicCrud → bool
-
Especifica si se deben agregar los bloc listeners de dynamicCrud
final
- apiRestEnableDebugLogs → bool
-
final
- authApiRestEnableDebugLogs → bool
-
final
- clientId → String
-
final
- clientSecret → String
-
final
- cloudDBEnableDebugLogs → bool
-
final
- coleccionAuth → String
-
final
-
coleccionesExtras
→ List<
String> -
final
- coleccionFuncionesBackend → String
-
final
-
customWidgetBuilders
→ Map<
String, CustomWidgetBuilder> -
final
- darkTheme → ThemeData?
-
final
- dynamicEnableDebugLogs → bool
-
final
- endpointApi → String
-
final
- endpointAuth → String
-
final
- endpointSocket → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- homePageBuilder → Widget Function(Widget)
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lightTheme → ThemeData?
-
final
- loginPageBuilder → Widget Function(Widget)?
-
final
- loginRoute → String?
-
final
- loginRouteWidget → Widget?
-
final
-
lstColeccionesExtrasAuth
→ List<
ItemModel> -
Si en la app se va poder configurar la seguridad para mas de una coleccion
se debe pasar una lista de colecciones extras
En esta lista debe estar el mismo valor que coleccionAuth. Los valores que posea debe tener el siguiente formato
{ "idItem":'usuariosENXSeguridad' "descripcionItem":'Seguridad de usuarios ENX' }, { "idItem":"genesisSeguridad", "descripcionItem":"Seguridad de genesis" }Todos los idItem deben terminar con la palabra Seguridad que es la que se encarga de administrar la seguridad de la coleccionfinal -
lstRouteAdicionales
→ Map<
String, dynamic Function(BuildContext, GoRouterState)> -
final
-
lstRouteAdicionalesLogin
→ Map<
String, dynamic Function(BuildContext, GoRouterState)> -
final
-
lstVistasSistema
→ List<
RouteItem> -
final
- onRedirect → dynamic Function(BuildContext, GoRouterState)?
-
final
- originColeccion → String
-
final
- redirectUri → RedirectUri
-
final
- rootRoute → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- soloColeccionesOrigen → bool
-
final
- title → String
-
final
- utilProviderEnableDebugLogs → bool
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< MyAppDynamic> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited